==> freevo-1.7.2.tar.gz: freevo-1.7.2/src/helpers/vtrelease.py <==
#!/usr/bin/env python
# -*- coding: iso-8859-1 -*-
# -----------------------------------------------------------------------
# vtrelease.py - release the ttys after pygame crash
# -----------------------------------------------------------------------
# $Id: vtrelease.py 9561 2007-05-11 18:22:36Z duncan $
#
# Notes:
#
# Todo:
#
# -----------------------------------------------------------------------
# Freevo - A Home Theater PC framework
# Copyright (C) 2002 Krister Lagerstrom, et al.
# Please see the file freevo/Docs/CREDITS for a complete list of authors.
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful, but
# WITHOUT ANY WARRANTY; without even the implied warranty of MER-
# CHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General
# Public License for more details.
#
# You should have received a copy of the GNU General Public License along
# with this program; if not, write to the Free Software Foundation, Inc.,
# 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
#
# -----------------------------------------------------------------------


import os
import sys
from fcntl import ioctl

if len(sys.argv)>1 and sys.argv[1] == '--help':
    print 'release the vt in case freevo crashed and still locks'
    print 'the framebuffer.'
    print
    print 'this script has no options'
    print
    sys.exit(0)


for i in range(1,7):
    try:
        fd = os.open('/dev/tty%s' % i, os.O_RDONLY | os.O_NONBLOCK)
        # set ioctl (tty, KDSETMODE, KD_TEXT)
        ioctl(fd, 0x4B3A, 0)
        os.close(fd)
    except:
        pass

==> freevo_1.8.1.orig.tar.gz: freevo-1.8.1/src/helpers/vtrelease.py <==
#!/usr/bin/env python
# -*- coding: iso-8859-1 -*-
# -----------------------------------------------------------------------
# vtrelease.py - release the ttys after pygame crash
# -----------------------------------------------------------------------
# $Id: vtrelease.py 10605 2008-04-02 21:22:35Z duncan $
#
# Notes:
#
# Todo:
#
# -----------------------------------------------------------------------
# Freevo - A Home Theater PC framework
# Copyright (C) 2002 Krister Lagerstrom, et al.
# Please see the file freevo/Docs/CREDITS for a complete list of authors.
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful, but
# WITHOUT ANY WARRANTY; without even the implied warranty of MER-
# CHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General
# Public License for more details.
#
# You should have received a copy of the GNU General Public License along
# with this program; if not, write to the Free Software Foundation, Inc.,
# 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
#
# -----------------------------------------------------------------------


import os
import sys
from fcntl import ioctl

if len(sys.argv)>1 and sys.argv[1] == '--help':
    print 'release the vt in case freevo crashed and still locks'
    print 'the framebuffer.'
    print
    print 'this script has no options'
    print
    sys.exit(0)


for i in range(1,7):
    try:
        tty_device = '/dev/tty%s' % i
        fd = os.open(tty_device, os.O_RDONLY | os.O_NONBLOCK)
        # set ioctl (tty, KDSETMODE, KD_TEXT)
        ioctl(fd, 0x4B3A, 0)
        os.close(fd)
    except:
        pass
